stylotool.src.freestylo API documentation

# Module `stylotool.src.freestylo`

## Sub-modules

`stylotool.src.freestylo.AlliterationAnnotation`
`stylotool.src.freestylo.ChiasmusAnnotation`
`stylotool.src.freestylo.Configs`
`stylotool.src.freestylo.EpiphoraAnnotation`
`stylotool.src.freestylo.MGHPreprocessor`
`stylotool.src.freestylo.MetaphorAnnotation`
`stylotool.src.freestylo.PolysyndetonAnnotation`
`stylotool.src.freestylo.SimilarityNN`
`stylotool.src.freestylo.TextObject`
`stylotool.src.freestylo.TextPreprocessor`
`stylotool.src.freestylo.freestylo_main`